@@ -1710,12 +1710,18 @@ public class DateTimeFormatterBuilder {
                     for (int i = min; i <= max; i++) {
                         property.set(i);
                         validValues.add(property.getAsShortText(locale));
+                        validValues.add(property.getAsShortText(locale).toLowerCase(locale));
+                        validValues.add(property.getAsShortText(locale).toUpperCase(locale));
                         validValues.add(property.getAsText(locale));
+                        validValues.add(property.getAsText(locale).toLowerCase(locale));
+                        validValues.add(property.getAsText(locale).toUpperCase(locale));
                     }
                     if ("en".equals(locale.getLanguage()) && iFieldType == DateTimeFieldType.era()) {
                         // hack to support for parsing "BCE" and "CE" if the language is English
                         validValues.add("BCE");
+                        validValues.add("bce");
                         validValues.add("CE");
+                        validValues.add("ce");
                         maxLength = 3;
                     }
                     array = new Object[] {validValues, new Integer(maxLength)};
